*******************************
*Multilevel Workshop I Examples
*June 20/21, 2013
*StatLab@UVa Library
*Michele Claibourn
*******************************

***Motivation***
**Multilevel data example: Comparative Study of Electoral Systems
use "C:\Users\mpc8t\Downloads\comparativeStudyElectoralSystems.dta", clear

describe
sort vcountry rid
list rid satisfy economy female age vcountry gdp gini yrs_dem in 1/5
list rid satisfy economy female age vcountry gdp gini yrs_dem in 10001/10005
list rid satisfy economy female age vcountry gdp gini yrs_dem in 20001/20005
xtset cid
xtsum satisfy economy female gdp gini yrs_dem


**Pitfalls of Pooling
use "C:\mpc\DataServices\Workshops\MultilevelWorkshops\pooledExample.dta", clear

*Pooled regression
scatter outdoorspend income || lfit outdoorspend income, ytitle("Outdoor Spending ($1000)") xtitle("Income ($1000)")  ///
	legend(off) title("Pooled Regression") subtitle("Outdoor Recreational Spending by Income")
*Pooled regression, with city labels
scatter outdoorspend income, mlabels(city) || lfit outdoorspend income || , ytitle("Outdoor Spending ($1000)") xtitle("Income ($1000)")  /// 
	legend(off) title("Pooled Regression") subtitle("Outdoor Recreational Spending by Income")
*Separate regressions
scatter outdoorspend income, mlabels(city) || line bfit income || line cfit income || line pfit income || , ytitle("Outdoor Spending ($1000)")  /// 
	xtitle("Income ($1000)") legend(off) title("Separate Regressions") subtitle("Outdoor Recreational Spending by Income")


**Varying slopes and intercepts
*Negative covariance
use "C:\mpc\DataServices\Workshops\MultilevelWorkshops\varyingExampleNegCov.dta", clear
twoway line school1 cses || line school2 cses || line school3 cses, title("Varying slopes and intercept") subtitle("(negative covariance)")  ///
	ytitle("Student Math Score") xtitle("Student Socio-Economic Status")

*Positive covariance
use "C:\mpc\DataServices\Workshops\MultilevelWorkshops\varyingExamplePosCov.dta", clear
twoway line school1 cses || line school2 cses || line school3 cses, title("Varying slopes and intercept") subtitle("(positive covariance)")  ///
	ytitle("Student Math Score") xtitle("Student Socio-Economic Status")


***Implementation and Interpretation***
**Multilevel Model Estimation
*Load High School and Beyond Data
use "C:\Users\mpc8t\Downloads\schools.dta", clear

describe
list id school female ses mathach meanses catholic in 1/5
list id school female ses mathach meanses catholic in 301/305
list id school female ses mathach meanses catholic in 601/605
xtset school
xtsum mathach cses

**One-way ANOVA with Random Effects
xtmixed mathach || school: , variance
est store roneway

*The intra-class correlation
estat icc
*A check, call the relevant estimated results directly: try "ereturn list" to see the available estimated objects")
display (exp(_b[lns1_1_1:_cons]))^2/((exp(_b[lns1_1_1:_cons]))^2 + (exp(_b[lnsig_e:_cons]))^2)

**Random Intercept
xtmixed mathach cses || school:, variance
est store rint

**Random Coefficients
xtmixed mathach cses  || school: cses, variance covar(un)
est store rcoef

*Is random coefficient statistically significant?
lrtest rcoef rint

**(Linear) Mixed Effects
gen csesbycath=cses*catholic
xtmixed mathach cses catholic csesbycath || school: cses, variance covar(un)
est store rlme
*Or, if you prefer to create the interaction on the fly using Stata's factor variables:
xtmixed mathach c.cses##catholic || school: cses, variance covar(un)
*Or, if you want to create the interaction on the fly and you find the last command confusing:
xtmixed mathach cses catholic c.cses#i.catholic || school: cses, variance covar(un)

*PRE: Intercept Variance
display 1 - (6.429708/8.238015)
*PRE: Coefficient Variance
display 1 - (.0242429/.0743896)

*Is random coefficient statistically significant?
quietly xtmixed mathach cses catholic csesbycath || school: , variance covar(un)
est store rlme2
lrtest rlme rlme2

*Or save estimated results as scalars and use results
est restore rlme
scalar tau1lme = (exp(_b[lns1_1_1:_cons]))^2
scalar tau0lme = (exp(_b[lns1_1_2:_cons]))^2
est restore rcoef
scalar tau1rcm = (exp(_b[lns1_1_1:_cons]))^2
scalar tau0rcm = (exp(_b[lns1_1_2:_cons]))^2

display 1 - (tau0lme/tau0rcm)
display 1 - (tau1lme/tau1rcm)


***The Linear Mixed-Effects Model
gen csesbymean=cses*meanses
xtmixed mathach cses catholic meanses csesbycath csesbymean || school: cses, variance covar(un)
est store lmefull

*Is random coefficient statistically significant?
xtmixed mathach cses catholic meanses csesbycath csesbymean || school: , variance covar(un)
est store lmefull2
lrtest lmefull lmefull2


